import extra_data


class Gotthard2Ctrl():
    def __init__(
        self,
        run_dc: extra_data.DataCollection,
        ctrl_src: str,
    ):
        """Read slow data.
        :param run_dir: EXtra-data RunDirectory DataCollection object.
        :param ctrl_src: Control source name for accessing slow data.
        """
        self.run_dc = run_dc
        self.ctrl_src = ctrl_src

    def get_bias_voltage(self):
        return self.run_dc[self.ctrl_src, "highVoltageMax"].as_single_value()

    def get_exposure_time(self):
        return round(
            self.run_dc[self.ctrl_src, "exposureTime"].as_single_value(), 4)

    def get_exposure_period(self):
        return round(
            self.run_dc[self.ctrl_src, "exposurePeriod"].as_single_value(), 4)

    def get_acquisition_rate(self):
        try:
            return float(
                self.run_dc.get_run_value(self.ctrl_src, "acquisitionRate"))
        except extra_data.PropertyNameError:
            pass

    def get_single_photon(self):
        if "singlePhoton.value" in self.run_dc.keys_for_source(self.ctrl_src):
            return bool(
                self.run_dc[self.ctrl_src, "singlePhoton"].as_single_value())
